@@ -1,4 +1,4 @@
-roxygen_available_palettes <- function() {
+roxygen_available_palettes <- function() { # nocov start
   palettes <- names(pride_data)
   c(
     "@section Available palettes:",
@@ -6,4 +6,4 @@ roxygen_available_palettes <- function() {
     paste0("* \x60", palettes, "\x60 (",
            lengths(lapply(palettes, palette_lgbtq)), " colors)")
   )
-}
+} # nocov end
